#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from onf_website.shared.expengine import EXPENGINE_CONTENT_TYPE

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.header.interfaces import IHeaderRendererSettings

# import packages
from pyams_file.schema import ImageField
from pyams_i18n.schema import I18nTextLineField
from pyams_sequence.schema import InternalReferenceField
from zope.interface import Interface, Attribute
from zope.schema import Bool

from onf_website import _


class IDefaultHeaderRendererSettings(IHeaderRendererSettings):
    """Default ONF header renderer settings"""

    can_use_context_illustration = Attribute("Can use context illustration as background?")

    use_context_illustration = Bool(title=_("Use context illustration"),
                                    required=False,
                                    default=True)

    no_use_context_illustration = Bool(title=_("Don't use context illustration?"),
                                       required=False,
                                       default=False)

    background = ImageField(title=_("Background image"),
                            description=_("Image displayed in header background"),
                            required=False)

    heading = I18nTextLineField(title=_('header-heading', default="Heading"),
                                description=_("Heading displayed on top above background illustration"),
                                required=False)
    
    logo = ImageField(title=_("Logo"),
                      description=_("Logo displayed in header"),
                      required=False)

    scroll_logo = ImageField(title=_("Scrolling logo"),
                             description=_("Alternate logo displayed in header while scrolling"),
                             required=False)

    accessibility_menu = Bool(title=_("Accessibility menu?"),
                              description=_("Set to 'no' to hide accessibility menu..."),
                              required=False,
                              default=True)

    search_menu = Bool(title=_("Search menu?"),
                       description=_("Set to 'no' to hide search menu..."),
                       required=False,
                       default=True)

    search_target = InternalReferenceField(title=_("Search form target"),
                                           description=_("Site or folder handling site search"),
                                           required=False)

    experiential_engine = InternalReferenceField(title=_("Experiential engine"),
                                                 description=_("Internal reference to experiential engine to include "
                                                               "into search form"),
                                                 content_type=EXPENGINE_CONTENT_TYPE,
                                                 required=False)

    top = Attribute("Top links list")

    menus = Attribute("Header menus")

    social_links_header = I18nTextLineField(title=_("Social networks header"),
                                            description=_("Social networks links header title"),
                                            required=False)

    social = Attribute("Social links")


class IDefaultHeaderMenu(Interface):
    """Default header menu marker interface"""


class IDefaultHeaderMenusContainer(Interface):
    """Default header menus container interface"""
