#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.features.menu.skin.interfaces import IONFNavigationPortletRendererSettings
from pyams_content.component.association.interfaces import IAssociationInfo
from pyams_content.features.menu.portlet.navigation.interfaces.simple import ISimpleNavigationPortletSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_skin.layer import IPyAMSLayer

# import packages
from onf_website.skin.public import owl_carousel_init, owl_navigation
from persistent import Persistent
from pyams_portal.portlet import PortletRenderer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config
from zope.interface import Interface, implementer
from zope.location import Location
from zope.schema.fieldproperty import FieldProperty

from onf_website import _


#
# Generic navigation portlet settings
#

@implementer(IONFNavigationPortletRendererSettings)
@factory_config(provided=IONFNavigationPortletRendererSettings)
class ONFNavigationTabsPortletRendererSettings(Persistent, Location):
    """ONF navigation portlet renderer settings"""

    subtitle = FieldProperty(IONFNavigationPortletRendererSettings['subtitle'])
    header = FieldProperty(IONFNavigationPortletRendererSettings['header'])


#
# Horizontal tabs navigation portlet renderer
#

@adapter_config(name='ONF::navigation-tabs',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-tabs.pt', layer=IPyAMSLayer)
class ONFNavigationTabsPortletRenderer(PortletRenderer):
    """ONF horizontal tab navigation portlet renderer"""

    label = _("ONF: Horizontal navigation tabs")
    weight = 10

    settings_interface = IONFNavigationPortletRendererSettings

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)


#
# Vertical illustrations portlet renderer
#

@adapter_config(name='ONF::navigation-illustration-vertical',
                context=(IPortalContext, IPyAMSLayer, Interface, ISimpleNavigationPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/navigation-illustration-vertical.pt', layer=IPyAMSLayer)
class ONFNavigationIllustationVerticalPortletRenderer(PortletRenderer):
    """ONF vertical illustrations navigation portlet renderer"""

    label = _("ONF: Vertical illustrations navigation")
    weight = 11

    settings_interface = IONFNavigationPortletRendererSettings
    resources = (owl_carousel_init, owl_navigation)

    @staticmethod
    def get_link_info(link):
        return IAssociationInfo(link)
