#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyams_utils.interfaces import VIEW_PERMISSION

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.shared.expengine.portlet.interfaces import IExpEnginePortletSettings

# import packages
from pyams_portal.portlet import PortletSettings, portlet_config, Portlet
from pyams_sequence.reference import get_reference_target
from pyams_utils.factory import factory_config
from pyams_utils.zodb import volatile_property
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty

from onf_website import _


EXPENGINE_PORTLET_NAME = 'onf_website.portlet.expengine'


@implementer(IExpEnginePortletSettings)
@factory_config(provided=IExpEnginePortletSettings)
class ExpEnginePortletSettings(PortletSettings):
    """Experiential engine portlet settings"""

    title = FieldProperty(IExpEnginePortletSettings['title'])
    reference = FieldProperty(IExpEnginePortletSettings['reference'])

    @volatile_property
    def target(self):
        return get_reference_target(self.reference)

    def get_target(self, state=None):
        if not state:
            return self.target
        else:
            return get_reference_target(self.reference, state)


@portlet_config(permission=VIEW_PERMISSION)
class ExpEnginePortlet(Portlet):
    """Experiential engine portlet"""

    name = EXPENGINE_PORTLET_NAME
    label = _("Experiential engine")

    toolbar_image = None
    toolbar_css_class = 'fa fa-fw fa-2x fa-life-ring'

    settings_factory = IExpEnginePortletSettings
